@@ -8,16 +8,16 @@ from enum import EnumMeta
 from math import ceil, sin
 from typing import TYPE_CHECKING, Any, Literal, cast, overload
 
-from vsaa import Nnedi3, Znedi3
+from vsaa import Nnedi3
 from vsexprtools import ExprOp, aka_expr_available, norm_expr
-from vsmasktools import retinex
 from vskernels import Bicubic, BicubicZopti, Bilinear, Scaler, ScalerT
+from vsmasktools import retinex
 from vsrgtools import bilateral, blur, gauss_blur, min_blur, replace_low_frequencies
 from vstools import (
-    ColorRange, ConvMode, CustomEnum, CustomIntEnum, CustomRuntimeError, DitherType, PlanesT, SingleOrArr,
-    SingleOrArrOpt, check_variable, clamp, core, depth, disallow_variable_format, disallow_variable_resolution,
-    fallback, get_depth, get_neutral_value, get_peak_value, get_y, join, normalize_planes, scale_8bit, scale_value,
-    split, vs, MissingT, MISSING, normalize_seq
+    MISSING, ColorRange, ConvMode, CustomEnum, CustomIntEnum, CustomRuntimeError, DitherType, MissingT, PlanesT,
+    SingleOrArr, SingleOrArrOpt, check_variable, clamp, core, depth, disallow_variable_format,
+    disallow_variable_resolution, fallback, get_depth, get_neutral_value, get_peak_value, get_y, join, normalize_planes,
+    normalize_seq, scale_8bit, scale_value, split, vs
 )
 
 from .bm3d import BM3D as BM3DM
@@ -953,15 +953,12 @@ class PelType(int, PelTypeBase):
                     pel_type = PelType.NNEDI3
 
         if pel_type == PelType.NNEDI3:
-            nnedicl, nnedi, znedi = (hasattr(core, ns) for ns in ('nnedi3cl', 'nnedi3', 'znedi3'))
-            do_nnedi = (nnedicl or nnedi) and not znedi
-
-            if not any((nnedi, znedi, nnedicl)):
+            if not any((hasattr(core, ns) for ns in ('nnedi3cl', 'nnedi3'))):
                 raise CustomRuntimeError('Missing any nnedi3 implementation!', PelType.NNEDI3)
 
             kwargs |= {'nsize': 0, 'nns': clamp(((pel - 1) // 2) + 1, 0, 4), 'qual': clamp(pel - 1, 1, 3)} | kwargs
 
-            pel_type = Nnedi3(**kwargs, opencl=nnedicl) if do_nnedi else Znedi3(**kwargs)
+            pel_type = Nnedi3(**kwargs)
 
         assert isinstance(pel_type, Scaler)
 
